# Generated by Django 3.2.12 on 2022-04-05 23:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('lti_provider', '0006_auto_20180205_1636'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lticoursecontext',
            name='lms_course_context',
            field=models.CharField(max_length=255, unique=True),
        ),
    ]
